@@ -111,7 +111,7 @@ async def test_11_split1(autojump_clock, tocky):  # pylint: disable=unused-argum
 
                     i.s()
 
-        await st.tg.spawn(watch)
+        st.tg.spawn(watch)
         async with st.client(1) as ci:
             assert (await ci.get(P(":"))).value == 420
             r = await ci.set(P("ping"), value="pong")
